@@ -1,4 +1,4 @@
 """Collection of reinforcement learning algorithms."""
 
+from . import trainer
 from .trainer import Trainer
-from .trainer import with_common_config
