@@ -1,42 +1,25 @@
 # pylint: disable=missing-module-docstring
 from ray.rllib.utils import override
 
-from raylab.agents import Trainer
-from raylab.agents import with_common_config
-from raylab.utils.dictionaries import deep_merge
+from raylab.agents import trainer
+from raylab.agents.trainer import Trainer
 from raylab.utils.replay_buffer import NumpyReplayBuffer
 
-BASE_CONFIG = with_common_config(
-    {
-        # === Policy ===
-        # Whether to optimize the policy's backend
-        "compile_policy": False,
-        # === Replay buffer ===
-        # Size of the replay buffer.
-        "buffer_size": 500000,
-        # === Optimization ===
-        # Wait until this many steps have been sampled before starting optimization.
-        "learning_starts": 0,
-        # === Common config defaults ===
-        "num_workers": 0,
-        "rollout_fragment_length": 1,
-        "batch_mode": "complete_episodes",
-        "train_batch_size": 128,
-    }
+
+@trainer.config("train_batch_size", 128, override=True)
+@trainer.config("batch_mode", "complete_episodes", override=True)
+@trainer.config("rollout_fragment_length", 1, override=True)
+@trainer.config("num_workers", 0, override=True)
+@trainer.config(
+    "learning_starts", 0, info="Sample this many steps before starting optimization."
 )
-
-
-def with_base_config(config):
-    """Returns the given config dict merged with the base off-policy configuration."""
-    return deep_merge(BASE_CONFIG, config, True)
-
-
+@trainer.config("buffer_size", 500000, info="Size of the replay buffer")
+@Trainer.with_base_specs
 class OffPolicyTrainer(Trainer):
     """Generic trainer for off-policy agents."""
 
-    # pylint: disable=attribute-defined-outside-init
+    # pylint:disable=attribute-defined-outside-init
     _name = ""
-    _default_config = None
     _policy = None
 
     @override(Trainer)
@@ -50,14 +33,14 @@ class OffPolicyTrainer(Trainer):
     @override(Trainer)
     def _train(self):
         pre_learning_steps = self.sample_until_learning_starts()
-        init_timesteps = self.tracker.num_steps_sampled
+        init_timesteps = self.metrics.num_steps_sampled
 
         worker = self.workers.local_worker()
         policy = worker.get_policy()
         stats = {}
         while not self._iteration_done(init_timesteps):
             samples = worker.sample()
-            self.tracker.num_steps_sampled += samples.count
+            self.metrics.num_steps_sampled += samples.count
             for row in samples.rows():
                 self.replay.add(row)
             stats.update(policy.get_exploration_info())
@@ -66,7 +49,7 @@ class OffPolicyTrainer(Trainer):
             for _ in range(samples.count):
                 batch = self.replay.sample(self.config["train_batch_size"])
                 stats.update(policy.learn_on_batch(batch))
-                self.tracker.num_steps_trained += batch.count
+                self.metrics.num_steps_trained += batch.count
 
         return self._log_metrics(stats, init_timesteps - pre_learning_steps)
 
@@ -86,15 +69,15 @@ class OffPolicyTrainer(Trainer):
         learning_starts = self.config["learning_starts"]
         worker = self.workers.local_worker()
         sample_count = 0
-        while self.tracker.num_steps_sampled + sample_count < learning_starts:
+        while self.metrics.num_steps_sampled + sample_count < learning_starts:
             samples = worker.sample()
             sample_count += samples.count
             for row in samples.rows():
                 self.replay.add(row)
 
         if sample_count:
-            self.tracker.num_steps_sampled += sample_count
-            self.global_vars["timestep"] = self.tracker.num_steps_sampled
+            self.metrics.num_steps_sampled += sample_count
+            self.global_vars["timestep"] = self.metrics.num_steps_sampled
             self.workers.foreach_worker(lambda w: w.set_global_vars(self.global_vars))
 
         return sample_count
