@@ -7,10 +7,10 @@ from ray.rllib import SampleBatch
 from ray.rllib.utils import override
 
 from raylab.agents.svg import SVGTorchPolicy
-from raylab.losses import OneStepSVG
 from raylab.policy import AdaptiveKLCoeffMixin
 from raylab.policy import EnvFnMixin
 from raylab.policy import TorchPolicy
+from raylab.policy.losses import OneStepSVG
 from raylab.pytorch.optim import get_optimizer_class
 
 
@@ -36,10 +36,10 @@ class SVGOneTorchPolicy(AdaptiveKLCoeffMixin, SVGTorchPolicy):
     @override(SVGTorchPolicy)
     def get_default_config():
         """Return the default config for SVG(1)"""
-        # pylint: disable=cyclic-import
-        from raylab.agents.svg.one import DEFAULT_CONFIG
+        # pylint: disable=cyclic-import,protected-access
+        from raylab.agents.svg.one import SVGOneTrainer
 
-        return DEFAULT_CONFIG
+        return SVGOneTrainer._default_config
 
     @override(SVGTorchPolicy)
     def make_module(self, obs_space, action_space, config):
@@ -49,8 +49,8 @@ class SVGOneTorchPolicy(AdaptiveKLCoeffMixin, SVGTorchPolicy):
     @override(SVGTorchPolicy)
     def make_optimizers(self):
         """PyTorch optimizer to use."""
-        cls = get_optimizer_class(self.config["torch_optimizer"], wrap=True)
-        options = self.config["torch_optimizer_options"]
+        cls = get_optimizer_class(self.config["torch_optimizer"]["type"], wrap=True)
+        options = self.config["torch_optimizer"]
         modules = {
             "model": self.module.model,
             "actor": self.module.actor,
@@ -95,7 +95,7 @@ class SVGOneTorchPolicy(AdaptiveKLCoeffMixin, SVGTorchPolicy):
 
         info.update(self.extra_grad_info(batch_tensors))
         info.update(self.update_kl_coeff(samples))
-        self.update_targets("critic", "target_critic")
+        self._update_polyak()
         return info
 
     @torch.no_grad()
