@@ -11,6 +11,7 @@ from torch.nn.utils import parameters_to_vector
 from torch.nn.utils import vector_to_parameters
 
 from raylab.policy import TorchPolicy
+from raylab.policy.action_dist import WrapStochasticPolicy
 from raylab.pytorch.optim import build_optimizer
 from raylab.pytorch.optim.hessian_free import conjugate_gradient
 from raylab.pytorch.optim.hessian_free import hessian_vector_product
@@ -24,21 +25,22 @@ class TRPOTorchPolicy(TorchPolicy):
     """Policy class for Trust Region Policy Optimization."""
 
     # pylint:disable=abstract-method
+    dist_class = WrapStochasticPolicy
 
     @staticmethod
     @override(TorchPolicy)
     def get_default_config():
         """Return the default configuration for TRPO."""
-        # pylint:disable=cyclic-import
-        from raylab.agents.trpo import DEFAULT_CONFIG
+        # pylint:disable=cyclic-import,protected-access
+        from raylab.agents.trpo import TRPOTrainer
 
-        return DEFAULT_CONFIG
+        return TRPOTrainer._default_config
 
     @override(TorchPolicy)
     def make_optimizers(self):
         return {
             "critic": build_optimizer(
-                self.module.critic, self.config["critic_optimizer"]
+                self.module.critic, self.config["torch_optimizer"]
             )
         }
 
